import { c as useRuntimeConfig, z as useStorage, l as defineEventHandler, j as createError } from '../nitro/node-server.mjs';
import { templateRender } from '@vue-email/compiler';
import 'node:http';
import 'node:https';
import 'fs';
import 'path';
import 'mongoose';
import 'requrl';
import 'node:fs';
import 'node:url';
import 'ipx';

const storageKey = "assets:emails";
async function useCompiler(filename, data, verbose = false) {
  const vueEmailOptions = useRuntimeConfig().public.vueEmail;
  const source = await useStorage(storageKey).getItem(filename);
  const keys = await useStorage(storageKey).getKeys();
  const components = [];
  for (const key of keys) {
    const value = await useStorage(storageKey).getItem(key);
    if (value && key.endsWith(".vue")) {
      components.push({
        name: key,
        source: value
      });
    }
  }
  if (!source)
    throw new Error(`Template ${filename} not found`);
  const template = await templateRender(filename, { source, components }, data, {
    verbose,
    options: {
      baseUrl: vueEmailOptions?.baseUrl,
      i18n: vueEmailOptions?.i18n
    }
  });
  return template;
}

const _file__get = defineEventHandler(async (event) => {
  try {
    const file = event.context.params && event.context.params.file ? event.context.params.file : null;
    const template = await useCompiler(file);
    if (!template) {
      throw createError({
        statusCode: 404,
        statusMessage: "Not Found"
      });
    }
    return template;
  } catch (error) {
    console.error(error);
    throw createError({
      statusCode: 500,
      statusMessage: "Internal Server Error"
    });
  }
});

export { _file__get as default };
//# sourceMappingURL=_file_.get.mjs.map
